@@ -20,24 +20,25 @@
 #define __LIBXMLPP_SCHEMABASE_H
 
 #include <libxml++/noncopyable.h>
+#include <string>
 
 namespace Glib
 {
-class LIBXMLPP_API ustring;
+class ustring;
 }
 
 namespace xmlpp
 {
-class LIBXMLPP_API Document;
+class Document;
 
 /** Base class for schemas, used for validation of XML files.
  *
  * @newin{2,38}
  */
-class LIBXMLPP_API SchemaBase : NonCopyable
+class SchemaBase : public NonCopyable
 {
 public:
-  SchemaBase();
+  SchemaBase() noexcept;
   ~SchemaBase() override;
 
   /** Parse a schema definition file.
@@ -45,7 +46,7 @@ public:
    * @param filename The URL of the schema.
    * @throws xmlpp::parse_error
    */
-  virtual void parse_file(const Glib::ustring& filename) = 0;
+  virtual void parse_file(const std::string& filename) = 0;
 
   /** Parse a schema definition from a string.
    * If another schema has been parsed before, that schema is replaced by the new one.
